#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   gi-freetype2
version:                2.0.5
visibility:             public
id:                     gi-freetype2-2.0.5-5DLRXoyq4ExArCSH5hs0g1
key:                    gi-freetype2-2.0.5-5DLRXoyq4ExArCSH5hs0g1
license:                LGPL-2.1-only
maintainer:             Iñaki García Etxebarria
author:                 Iñaki García Etxebarria
homepage:               https://github.com/haskell-gi/haskell-gi
synopsis:               freetype2 bindings
description:            Bindings for freetype2, autogenerated by haskell-gi.
category:               Bindings
abi:                    97f537a10ee0b8ec502529289319fe88
exposed:                True
exposed-modules:
    GI.Freetype2 GI.Freetype2.Config GI.Freetype2.Structs
    GI.Freetype2.Structs.Bitmap GI.Freetype2.Structs.Face
    GI.Freetype2.Structs.Library

import-dirs:            /usr/lib/ghc-9.6.6/site-local/gi-freetype2-2.0.5
library-dirs:
    /usr/lib/ghc-9.6.6/site-local/gi-freetype2-2.0.5 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/gi-freetype2-2.0.5 /usr/lib

dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-gi-freetype2
hs-libraries:           HSgi-freetype2-2.0.5-5DLRXoyq4ExArCSH5hs0g1
extra-libraries:        freetype
extra-libraries-static: freetype dl bz2 png16 m m z brotlidec brotlicommon
include-dirs:
    /usr/include/freetype2 /usr/include /usr/include/libpng16

depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    haskell-gi-0.26.17-HLmiQHnAhvv5CvHX3mnUPW
    haskell-gi-base-0.26.9-A51M6LjdiVN4RjdHJdLeji
    haskell-gi-overloading-1.0-6w3IXGDooXgu3RA2LfTuf text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-gi-freetype2/html/gi-freetype2.haddock

haddock-html:           /usr/share/doc/haskell-gi-freetype2/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

